@@ -1,12 +1,9 @@
-use 5.006;
-use warnings;
-use strict;
-package Number::Nary;
-{
-  $Number::Nary::VERSION = '1.100312';
-}
+package Number::Nary 1.100313;
 # ABSTRACT: encode and decode numbers as n-ary strings
 
+use strict;
+use warnings;
+
 use Carp qw(croak);
 use Scalar::Util 0.90 qw(reftype);
 use List::MoreUtils 0.09 qw(uniq);
@@ -31,6 +28,58 @@ sub _generate_codec_pair {
   return \%pair;
 }
 
+#pod =head1 SYNOPSIS
+#pod
+#pod This module lets you convert numbers into strings that encode the number using
+#pod the digit set of your choice.  For example, you could get routines to convert
+#pod to and from hex like so:
+#pod
+#pod   my ($enc_hex, $dec_hex) = n_codec('0123456789ABCDEF');
+#pod
+#pod   my $hex = $enc_hex->(255);  # sets $hex to FF
+#pod   my $num = $dec_hex->('A0'); # sets $num to 160
+#pod
+#pod This would be slow and stupid, since Perl already provides the means to easily
+#pod and quickly convert between decimal and hex representations of numbers.
+#pod Number::Nary's utility comes from the fact that it can encode into bases
+#pod composed of arbitrary digit sets.
+#pod
+#pod   my ($enc, $dec) = n_codec('0123'); # base 4 (for working with nybbles?)
+#pod
+#pod   # base64
+#pod   my ($enc, $dec) = n_codec(
+#pod     join('', 'A' .. 'Z', 'a' .. 'z', 0 .. 9, '+', '/', '=')
+#pod   );
+#pod
+#pod =func n_codec
+#pod
+#pod   my ($encode_sub, $decode_sub) = n_codec($digit_string, \%arg);
+#pod
+#pod This routine returns a reference to a subroutine which will encode numbers into
+#pod the given set of digits and a reference which will do the reverse operation.
+#pod
+#pod The digits may be given as a string or an arrayref.  This routine will croak if
+#pod the set of digits contains repeated digits, or if there could be ambiguity
+#pod in decoding a string of the given digits.  (Number::Nary is overly aggressive
+#pod about weeding out possibly ambiguous digit sets, for the sake of the author's
+#pod sanity.)
+#pod
+#pod The encode sub will croak if it is given input other than a non-negative
+#pod integer. 
+#pod
+#pod The decode sub will croak if given a string that contains characters not in the
+#pod digit string, or, for fixed-string digit sets, if the lenth of the string to
+#pod decode is not a multiple of the length of the component digits.
+#pod
+#pod Valid arguments to be passed in the second parameter are:
+#pod
+#pod   predecode  - if given, this coderef will be used to preprocess strings
+#pod                passed to the decoder
+#pod
+#pod   postencode - if given, this coderef will be used to postprocess strings
+#pod                produced by the encoder
+#pod
+#pod =cut
 
 sub _split_len_iterator {
   my ($length) = @_;
@@ -156,11 +205,66 @@ sub n_codec {
   return ($encode_sub, $decode_sub);
 }
 
+#pod =func n_encode
+#pod
+#pod   my $string = n_encode($value, $digit_string);
+#pod
+#pod This encodes the given value into a string using the given digit string.  It is
+#pod written in terms of C<n_codec>, above, so it's not efficient at all for
+#pod multiple uses in one process.
+#pod
+#pod =func n_decode
+#pod
+#pod   my $number = n_decode($string, $digit_string);
+#pod
+#pod This is the decoding equivalent to C<n_encode>, above.
+#pod
+#pod =cut
 
 # If you really can't stand using n_codec, you could memoize these.
 sub n_encode { (n_codec($_[1]))[0]->($_[0]) }
 sub n_decode { (n_codec($_[1]))[1]->($_[0]) }
 
+#pod =head1 EXPORTS
+#pod
+#pod C<n_codec> is exported by default.  C<n_encode> and C<n_decode> are exported.
+#pod
+#pod Pairs of routines to encode and decode may be imported by using the
+#pod C<codec_pair> group as follows:
+#pod
+#pod   use Number::Nary -codec_pair => { digits => '01234567', -suffix => '8' };
+#pod
+#pod   my $encoded = encode8($number);
+#pod   my $decoded = decode8($encoded);
+#pod
+#pod For more information on this kind of exporting, see L<Sub::Exporter>.
+#pod
+#pod =head1 SECRET ORIGINS
+#pod
+#pod I originally used this system to produce unique worksheet names in Excel.  I
+#pod had a large report generating system that used Win32::OLE, and to keep track of
+#pod what was where I'd Storable-digest the options used to produce each worksheet
+#pod and then n-ary encode them into the set of characters that were valid in
+#pod worksheet names.  Working out that set of characters was by far the hardest
+#pod part.
+#pod
+#pod =head1 ACKNOWLEDGEMENTS
+#pod
+#pod Thanks, Jesse Vincent.  When I remarked, on IRC, that this would be trivial to
+#pod do, he said, "Great.  Would you mind doing it?"  (Well, more or less.)  It was
+#pod a fun little distraction.
+#pod
+#pod Mark Jason Dominus and Michael Peters offered some useful advice on how to weed
+#pod out ambiguous digit sets, enabling me to allow digit sets made up of
+#pod varying-length digits.
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod L<Math::BaseCalc> is in the same problem space wth Number::Nary.  It provides
+#pod only an OO interface and does not reliably handle multicharacter digits or
+#pod recognize ambiguous digit sets.
+#pod
+#pod =cut
 
 1; # my ($encode_sub, $decode_sub) = n_codec('8675309'); # jennynary
 
@@ -168,13 +272,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Number::Nary - encode and decode numbers as n-ary strings
 
 =head1 VERSION
 
-version 1.100312
+version 1.100313
 
 =head1 SYNOPSIS
 
@@ -199,6 +305,16 @@ composed of arbitrary digit sets.
     join('', 'A' .. 'Z', 'a' .. 'z', 0 .. 9, '+', '/', '=')
   );
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 FUNCTIONS
 
 =head2 n_codec
@@ -284,11 +400,27 @@ recognize ambiguous digit sets.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
+
+=head1 CONTRIBUTORS
+
+=for stopwords Ricardo SIGNES Signes
+
+=over 4
+
+=item *
+
+Ricardo SIGNES <rjbs@codesimply.com>
+
+=item *
+
+Ricardo Signes <rjbs@semiotic.systems>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
